@@ -1,6 +1,6 @@
 /*******************************************************************
 *
-* This file is part of the KDE project "Bovo"
+* Copyright 2009  Pelladi Gabor <pelladigabor@gmail.com>
 *
 * Bovo is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -20,23 +20,25 @@
 ********************************************************************/
 
 
-/**
- * @file aigabor.cc implementing the AiGabor class
- */
-
-#include <QTime>
-#include <QtConcurrent>
 #include "aigabor.h"
 
 #include "coord.h"
 #include "dimension.h"
 #include "move.h"
 
+#include <QTime>
+#include <QThread>
+#include <QtConcurrentRun>
+
 using namespace bovo;
 
 /** namespace for AI stuff */
 namespace ai {
 
+/**
+ * @file aigabor.cc implementing the AiGabor class
+ */
+
 AiGabor::AiGabor(const Dimension& dimension, KgDifficultyLevel::StandardLevel skill, 
        Player player) : m_player(player), m_minThink(200) {
     m_ai = new AiInterface();
